@@ -318,6 +318,7 @@ yf::Z3950Client::Z3950Client() :  m_p(new yf::Z3950Client::Rep)
     m_p->m_init_timeout_sec = 10;
     m_p->m_general_timeout_sec = 30;
     m_p->m_max_sockets = 0;
+    m_p->m_max_sockets_timeout_sec = 15;
     m_p->m_force_close = false;
     m_p->m_client_ip = false;
     m_p->m_bind_host = false;
@@ -449,8 +450,8 @@ yf::Z3950Client::Assoc *yf::Z3950Client::Rep::get_assoc(Package &package)
                     no_not_in_use++;
             }
         }
-        yaz_log(YLOG_LOG, "Found %d/%d connections for %s", number, max_sockets,
-                target.c_str());
+        yaz_log(YLOG_LOG, "Found num=%d/max=%d/idle=%d connections for %s",
+                number, max_sockets, no_not_in_use, target.c_str());
         if (number < max_sockets)
             break;
         if (no_not_in_use == 0) // all in use..
