@@ -31,10 +31,10 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <yaz/log.h>
 
-#define BOOST_AUTO_TEST_MAIN
+#define BOOST_TEST_MAIN
 #define BOOST_TEST_DYN_LINK
 
-#include <boost/test/auto_unit_test.hpp>
+#include <boost/test/unit_test.hpp>
 
 using namespace boost::unit_test;
 namespace mp = metaproxy_1;
@@ -110,7 +110,7 @@ BOOST_AUTO_TEST_CASE( test_filter_rewrite_1 )
         mp::odr odr;
         Z_GDU *gdu_req = z_get_HTTP_Request_uri(odr,
             "https://proxyhost/proxypath/targetsite/page1.html", 0, 1);
-        
+
         Z_HTTP_Request *hreq = gdu_req->u.HTTP_Request;
         z_HTTP_header_set(odr, &hreq->headers,
                           "X-Metaproxy-SkipLink", ".* skiplink.com" );
